@@ -1,19 +1,20 @@
 """Internally used rule classes."""
 from __future__ import annotations
 
+import inspect
 import logging
+from pathlib import Path
 from typing import TYPE_CHECKING, Any
 
-if TYPE_CHECKING:
-    from typing import Optional
+from ansiblelint.constants import RULE_DOC_URL
 
-    from ansiblelint.constants import odict
+if TYPE_CHECKING:
     from ansiblelint.errors import MatchError
     from ansiblelint.file_utils import Lintable
 
 _logger = logging.getLogger(__name__)
 LOAD_FAILURE_MD = """\
-## load-failure
+# load-failure
 
 Linter failed to process a YAML file, probably because it is either:
 
@@ -36,7 +37,6 @@ class BaseRule:
     id: str = ""
     tags: list[str] = []
     description: str = ""
-    help: str = ""  # markdown help (automatically loaded from `<rule>.md`)
     version_added: str = ""
     severity: str = ""
     link: str = ""
@@ -47,6 +47,25 @@ class BaseRule:
     # _order 1 for rules that check that data can be loaded
     # _order 5 implicit for normal rules
     _order: int = 5
+    _help: str | None = None
+
+    @property
+    def help(self) -> str:
+        """Return a help markdown string for the rule."""
+        if self._help is None:
+            self._help = ""
+            md_file = (
+                Path(inspect.getfile(self.__class__)).parent
+                / f"{self.id.replace('-', '_')}.md"
+            )
+            if md_file.exists():
+                self._help = md_file.read_text(encoding="utf-8")
+        return self._help
+
+    @property
+    def url(self) -> str:
+        """Return rule documentation url."""
+        return self.link or RULE_DOC_URL + self.id + "/"
 
     @property
     def shortdesc(self) -> str:
@@ -62,9 +81,10 @@ class BaseRule:
                     matches.extend(method(file))
                 except Exception as exc:  # pylint: disable=broad-except
                     _logger.warning(
-                        "Ignored exception from %s.%s: %s",
+                        "Ignored exception from %s.%s while processing %s: %s",
                         self.__class__.__name__,
                         method,
+                        str(file),
                         exc,
                     )
         else:
@@ -77,7 +97,7 @@ class BaseRule:
 
     def matchtask(
         self, task: dict[str, Any], file: Lintable | None = None
-    ) -> bool | str | MatchError:
+    ) -> bool | str | MatchError | list[MatchError]:
         """Confirm if current rule is matching a specific task.
 
         If ``needs_raw_task`` (a class level attribute) is ``True``, then
@@ -94,7 +114,7 @@ class BaseRule:
         """Return matches found for a specific YAML text."""
         return []
 
-    def matchplay(self, file: Lintable, data: odict[str, Any]) -> list[MatchError]:
+    def matchplay(self, file: Lintable, data: dict[str, Any]) -> list[MatchError]:
         """Return matches found for a specific playbook."""
         return []
 
@@ -126,12 +146,6 @@ class RuntimeErrorRule(BaseRule):
     """Unexpected internal error."""
 
     id = "internal-error"
-    description = (
-        "This error can be caused by internal bugs but also by "
-        "custom rules. Instead of just stopping linter we generate the errors and "
-        "continue processing. This allows users to add this rule to their warn list until "
-        "the root cause is fixed."
-    )
     severity = "VERY_HIGH"
     tags = ["core"]
     version_added = "v5.0.0"
@@ -159,3 +173,14 @@ class LoadingFailureRule(BaseRule):
     version_added = "v4.3.0"
     help = LOAD_FAILURE_MD
     _order = 0
+
+
+class WarningRule(BaseRule):
+    """Other warnings detected during run."""
+
+    id = "warning"
+    severity = "LOW"
+    # should remain experimental as that would keep it warning only
+    tags = ["core", "experimental"]
+    version_added = "v6.8.0"
+    _order = 0
