@@ -4,13 +4,10 @@ from __future__ import annotations
 import sys
 from typing import TYPE_CHECKING, Any
 
+from ansiblelint.constants import LINE_NUMBER_KEY
 from ansiblelint.rules import AnsibleLintRule
-from ansiblelint.utils import LINE_NUMBER_KEY
 
 if TYPE_CHECKING:
-    from typing import Optional
-
-    from ansiblelint.constants import odict
     from ansiblelint.errors import MatchError
     from ansiblelint.file_utils import Lintable
 
@@ -27,7 +24,7 @@ class NoPromptingRule(AnsibleLintRule):
     severity = "VERY_LOW"
     version_added = "v6.0.3"
 
-    def matchplay(self, file: Lintable, data: odict[str, Any]) -> list[MatchError]:
+    def matchplay(self, file: Lintable, data: dict[str, Any]) -> list[MatchError]:
         """Return matches found for a specific playbook."""
         # If the Play uses the 'vars_prompt' section to set variables
 
@@ -37,11 +34,10 @@ class NoPromptingRule(AnsibleLintRule):
         vars_prompt = data.get("vars_prompt", None)
         if not vars_prompt:
             return []
-
         return [
             self.create_matcherror(
                 message="Play uses vars_prompt",
-                linenumber=vars_prompt[LINE_NUMBER_KEY],
+                linenumber=vars_prompt[0][LINE_NUMBER_KEY],
                 filename=file,
             )
         ]
@@ -73,5 +69,6 @@ if "pytest" in sys.modules:
         rules = RulesCollection(options=options)
         rules.register(NoPromptingRule())
         results = Runner("examples/playbooks/no-prompting.yml", rules=rules).run()
-        assert len(results) == 1
-        assert results[0].rule.id == "no-prompting"
+        assert len(results) == 2
+        for result in results:
+            assert result.rule.id == "no-prompting"
